@@ -14,8 +14,7 @@ import os
 import sys
 import urllib3
 
-from getSequence.get_sequence import seq_from_name as _seq_from_name
-from getSequence.get_sequence import fetch_sequence as _fetch_sequence
+from getSequence.get_sequence import seq_from_uniprot as _seq_from_uniprot
 from getSequence.getsequence_exceptions import RetreiveSequenceError
 
 def getseq(name, just_sequence=False):
@@ -36,20 +35,17 @@ def getseq(name, just_sequence=False):
 	By default, returns a list where:
 		[0] = full Uniprot ID
 		[1] = Protein sequence
-		[2] = Just the Uniprot ID
 	'''
 
 	try:
-		fullID_seq_name = _seq_from_name(name)
+		fullID_seq_name = _seq_from_uniprot(name)
 		if just_sequence == True:
 			return fullID_seq_name[1]
 		else:
 			return fullID_seq_name
 	except:
-		if just_sequence == False:
-			return _fetch_sequence(name, return_full_id=True)
-		else:
-			return _fetch_sequence(name)		
+		raise RetreiveSequenceError('Unable to retrieve sequence.')
+	
 
 
 
